/* Estimate hazard models for sexual initiation, with additional variables. */
/* Run in folder with the created datasets. */



// EXTRACT SCHOOL IDS FOR HIGH SCHOOL

set more off

* Load and collapse analytic file:

use dynamic_R if cohort==12

contract commid scid

* Find communities with multiple schools:
* (indicates data error, as we restricted to 12th grade)

duplicates tag commid, gen(dupcom)

list if dupcom==1

* Drop the duplicate schools with few students:

drop if dupcom==1 & _f < 5

keep commid scid
save temp, replace



// CREATE PANEL DATASET

* Import individual data:

use variables_R

* Give all ninth graders the scid of HS:

rename scid scid_true

sort commid
merge m:1 commid using temp
drop _m

* Merge with school data:

sort scid
merge m:1 scid using schoolinfo
drop a1*
keep if _m==3
drop _m

* Merge with virginity status over time:

destring aid, gen(id)
sort id
merge id using quarterly, keep(t nonvirg)
tab _m
keep if _m == 3
drop _m

* Consistent panel, remove observations that drop out:

xtset id t

drop if t == 146
by id: egen complete = max(t)
replace complete = (complete==145 | complete==146)
keep if complete == 1 | cohort == 12
drop complete

* Merge in aggregates (peer and supply nonvirginity rates):

destring commid, replace
gen byte gen = bio_sex

gen aggid = 1000*commid + 10*cohort + gen

sort aggid t

merge m:1 aggid t using agg_qtr
keep if _m==3
drop _m

* Check sample size (16,444):

xtset
xtdes



// CONSTRUCT VARIABLES

* Collect variable names:

global mainvars black pcoll younger only 
global mainpeer black_P pcoll_P younger_P only_P 

global schoolpols sexed1 sexed2 fp_onsite fp_noref daycare parenting

* Binary variable for parental education:

gen byte pcoll = paredu >= 3

* Peer group population:

bysort commid cohort bio_sex t: egen pop_P = count(nonvirg)
replace pop_P = pop_P-1

* Peer group means:

foreach var of varlist $mainvars  {
  by commid cohort bio_sex t: egen `var'_P = sum(`var')
  replace `var'_P = (`var'_P - `var') / pop_P
  }

foreach var of varlist *_P  {
  replace `var' = 0 if pop_P == 0
  }

* School policy variables:

gen byte sexed1 = a25c==1 | a25d==1
label variable sexed1 "Sex ed in 9th or 10th grade"

gen byte sexed2 = a25e==1 | a25f==1
label variable sexed2 "Sex ed in 11th or 12th grade"

gen byte fp_onsite = a28g==1
gen byte fp_noref = a28g==4

gen byte daycare = a28q==1

gen byte bootpreg = a29a==0
gen byte parenting = a29d==1



// PANEL VARIABLES

* Initial conditions:

gen owninit = hbar if t==138
gen mktinit = market0 if t==138

xtset
replace owninit = L.owninit if owninit==.
replace mktinit = L.mktinit if mktinit==.

* Average of peer and supply group nonvirginity rate:

gen bothlag = (ownlag + mktlag0)/2

* Make the estimation sample consistent:
* (sets ownlag to missing if supply lag is missing)

replace ownlag = . if mktlag0 == .

* Simple time period variable:

replace t = t-138
format t %9.0g

* Age (as quarters in high school):

gen age = cohort + (t-1)/4

* Set age to exclude individuals in isolated ninth grade:

replace age = 0 if grd9sep & age < 10

* Save:

save hazard, replace



// LOGIT DISCRETE HAZARD MODELS

xtset id t

// A) Using Same-Gender Peer Group Alone

* Boys:

logit nonvirg age ownlag if L.nonvirg==0 & age>=9 & bio_sex==1
  outreg2 age ownlag using hazard_peer, long dec(2) noaster text replace

logit nonvirg age ownlag owninit mktinit if L.nonvirg==0 & age>=9 & bio_sex==1
  outreg2 age ownlag using hazard_peer, long dec(2) noaster text append

logit nonvirg age ownlag owninit mktinit $mainvars if L.nonvirg==0 & age>=9 & bio_sex==1
  outreg2 age ownlag $mainvars using hazard_peer, long dec(2) noaster text append

logit nonvirg age ownlag owninit mktinit $mainvars $mainpeer urban if L.nonvirg==0 & age>=9 & bio_sex==1
  outreg2 age ownlag $mainvars using hazard_peer, long dec(2) noaster text append

logit nonvirg age ownlag owninit mktinit $mainvars $mainpeer $schoolpols urban if L.nonvirg==0 & age>=9 & bio_sex==1
  outreg2 age ownlag $mainvars $schoolpols using hazard_peer, long dec(2) noaster text append

logit nonvirg age ownlag $mainvars $mainpeer i.commid if L.nonvirg==0 & age>=9 & bio_sex==1
  outreg2 age ownlag $mainvars using hazard_peer, long dec(2) noaster text append

* Girls:

logit nonvirg age ownlag if L.nonvirg==0 & age>=9 & bio_sex==2
  outreg2 age ownlag using hazard_peer, long dec(2) noaster text append

logit nonvirg age ownlag owninit mktinit if L.nonvirg==0 & age>=9 & bio_sex==2
  outreg2 age ownlag using hazard_peer, long dec(2) noaster text append

logit nonvirg age ownlag owninit mktinit $mainvars if L.nonvirg==0 & age>=9 & bio_sex==2
  outreg2 age ownlag $mainvars using hazard_peer, long dec(2) noaster text append

logit nonvirg age ownlag owninit mktinit $mainvars $mainpeer urban if L.nonvirg==0 & age>=9 & bio_sex==2
  outreg2 age ownlag $mainvars using hazard_peer, long dec(2) noaster text append

logit nonvirg age ownlag owninit mktinit $mainvars $mainpeer $schoolpols urban if L.nonvirg==0 & age>=9 & bio_sex==2
  outreg2 age ownlag $mainvars $schoolpols using hazard_peer, long dec(2) noaster text append

logit nonvirg age ownlag $mainvars $mainpeer i.commid if L.nonvirg==0 & age>=9 & bio_sex==2
  outreg2 age ownlag $mainvars using hazard_peer, long dec(2) noaster sortvar(age ownlag $mainvars $schoolpols) tex(fragment) append

// B) Using Peer and Supply Group Combined

* Boys:

logit nonvirg age bothlag if L.nonvirg==0 & age>=9 & bio_sex==1
  outreg2 age bothlag using hazard_combo, long dec(2) noaster text replace

logit nonvirg age bothlag owninit mktinit if L.nonvirg==0 & age>=9 & bio_sex==1
  outreg2 age bothlag using hazard_combo, long dec(2) noaster text append

logit nonvirg age bothlag owninit mktinit $mainvars if L.nonvirg==0 & age>=9 & bio_sex==1
  outreg2 age bothlag $mainvars using hazard_combo, long dec(2) noaster text append

logit nonvirg age bothlag owninit mktinit $mainvars $mainpeer urban if L.nonvirg==0 & age>=9 & bio_sex==1
  outreg2 age bothlag $mainvars using hazard_combo, long dec(2) noaster text append

logit nonvirg age bothlag owninit mktinit $mainvars $mainpeer $schoolpols urban if L.nonvirg==0 & age>=9 & bio_sex==1
  outreg2 age bothlag $mainvars $schoolpols using hazard_combo, long dec(2) noaster text append

logit nonvirg age bothlag $mainvars $mainpeer i.commid if L.nonvirg==0 & age>=9 & bio_sex==1
  outreg2 age bothlag $mainvars using hazard_combo, long dec(2) noaster text append

* Girls:

logit nonvirg age bothlag if L.nonvirg==0 & age>=9 & bio_sex==2
  outreg2 age bothlag using hazard_combo, long dec(2) noaster text append

logit nonvirg age bothlag owninit mktinit if L.nonvirg==0 & age>=9 & bio_sex==2
  outreg2 age bothlag using hazard_combo, long dec(2) noaster text append

logit nonvirg age bothlag owninit mktinit $mainvars if L.nonvirg==0 & age>=9 & bio_sex==2
  outreg2 age bothlag $mainvars using hazard_combo, long dec(2) noaster text append

logit nonvirg age bothlag owninit mktinit $mainvars $mainpeer urban if L.nonvirg==0 & age>=9 & bio_sex==2
  outreg2 age bothlag $mainvars using hazard_combo, long dec(2) noaster text append

logit nonvirg age bothlag owninit mktinit $mainvars $mainpeer $schoolpols urban if L.nonvirg==0 & age>=9 & bio_sex==2
  outreg2 age bothlag $mainvars $schoolpols using hazard_combo, long dec(2) noaster text append

logit nonvirg age bothlag $mainvars $mainpeer i.commid if L.nonvirg==0 & age>=9 & bio_sex==2
  outreg2 age bothlag $mainvars using hazard_combo, long dec(2) noaster sortvar(age bothlag $mainvars $schoolpols) tex(fragment) append

// C) Using Peer and Supply Group Separately

* Boys:

logit nonvirg age ownlag mktlag0 if L.nonvirg==0 & age>=9 & bio_sex==1
  outreg2 age ownlag mktlag0 using hazard_both, long dec(2) noaster text replace

logit nonvirg age ownlag mktlag0 owninit mktinit if L.nonvirg==0 & age>=9 & bio_sex==1
  outreg2 age ownlag mktlag0 using hazard_both, long dec(2) noaster text append

logit nonvirg age ownlag mktlag0 owninit mktinit $mainvars if L.nonvirg==0 & age>=9 & bio_sex==1
  outreg2 age ownlag mktlag0 $mainvars using hazard_both, long dec(2) noaster text append

logit nonvirg age ownlag mktlag0 owninit mktinit $mainvars $mainpeer urban if L.nonvirg==0 & age>=9 & bio_sex==1
  outreg2 age ownlag mktlag0 $mainvars using hazard_both, long dec(2) noaster text append

logit nonvirg age ownlag mktlag0 owninit mktinit $mainvars $mainpeer $schoolpols urban if L.nonvirg==0 & age>=9 & bio_sex==1
  outreg2 age ownlag mktlag0 $mainvars $schoolpols using hazard_both, long dec(2) noaster text append

logit nonvirg age ownlag mktlag0 $mainvars $mainpeer i.commid if L.nonvirg==0 & age>=9 & bio_sex==1
  outreg2 age ownlag mktlag0 $mainvars using hazard_both, long dec(2) noaster text append

* Girls:

logit nonvirg age ownlag mktlag0 if L.nonvirg==0 & age>=9 & bio_sex==2
  outreg2 age ownlag mktlag0 using hazard_both, long dec(2) noaster text append

logit nonvirg age ownlag mktlag0 owninit mktinit if L.nonvirg==0 & age>=9 & bio_sex==2
  outreg2 age ownlag mktlag0 using hazard_both, long dec(2) noaster text append

logit nonvirg age ownlag mktlag0 owninit mktinit $mainvars if L.nonvirg==0 & age>=9 & bio_sex==2
  outreg2 age ownlag mktlag0 $mainvars using hazard_both, long dec(2) noaster text append

logit nonvirg age ownlag mktlag0 owninit mktinit $mainvars $mainpeer urban if L.nonvirg==0 & age>=9 & bio_sex==2
  outreg2 age ownlag mktlag0 $mainvars using hazard_both, long dec(2) noaster text append

logit nonvirg age ownlag mktlag0 owninit mktinit $mainvars $mainpeer $schoolpols urban if L.nonvirg==0 & age>=9 & bio_sex==2
  outreg2 age ownlag mktlag0 $mainvars $schoolpols using hazard_both, long dec(2) noaster text append

logit nonvirg age ownlag mktlag0 $mainvars $mainpeer i.commid if L.nonvirg==0 & age>=9 & bio_sex==2
  outreg2 age ownlag mktlag0 $mainvars using hazard_both, long dec(2) noaster sortvar(age ownlag mktlag0 $mainvars $schoolpols) tex(fragment) append
