/* Make final estimation file for the dynamic model, to be used in R. */



// LOAD FILES

cd created

use covariates

merge aid using inschool, nokeep keep(s1 s2 s3)
tab _m
rename _m mergeInS

sort scid
merge scid using schoolinfo, nokeep
tab _m
rename _m mergeSch



// CREATE VARIABLES

* Grade cohort:
gen byte cohort = h1gi20
replace cohort = s3 if cohort > 12 & s3 < 13

* Biological:
gen byte hisp = h1gi4 == 1
gen byte black = h1gi6b == 1
gen byte only = h1hr14 == 1
gen byte younger = h1hr15 > 1 & h1hr15 < 90
gen byte ovrwgt = h1gh28 == 4 | h1gh28 == 5
gen byte puberty = h1fp4 < 12
replace puberty = 1 if h1mp2==3 | h1mp2==4

* Socioeconomic:
gen byte mom_mar = pa10 == 2
gen byte blk_mar = black*mom_mar
gen byte upinc = pa55 > 50 & pa55 < 1000
gen byte expcoll = h1ee2 == 5
gen byte momedu = (pa12==4) + 2*(pa12==6 | pa12==7) + 3*(pa12==8) + 4*(pa12==9)
gen byte dadedu = (pb8==4) + 2*(pb8==6 | pb8==7) + 3*(pb8==8) + 4*(pb8==9)
gen byte paredu = max(momedu,dadedu)
gen byte pborn = pa3 == 0

* Contextual:
gen byte urban = aurban == 1
gen byte blk_urb = black*urban
tab aregion, gen(region_)
drop region_3

* Institutional (is 9th grade in high school):
tab commid a1k if cohort==10
gen byte grd9sep = (commid == "411" | commid == "442" | commid == "472" | commid == "477") 
* NOTE: For commid 472, scid 072 shows 9th graders.  However there is a comment 
*   in "Schinfo.xpt": "Ninth grade is at a campus 4 miles away from grades 10-12".
tab commid a1k if cohort==10 & grd9sep==1
tab commid a1k if cohort==10 & grd9sep==0



// SAMPLE RESTRICTIONS

* Interview date:
drop if imonth == 1
drop if iyear == 94

* Missing group identifying variables:
drop if cohort == 6 | cohort > 12
drop if scid == "999"
drop if bio_sex > 2

* Drop small schools:
table cohort bio, by(commid)
drop if commid > "479"

* Drop all-boys school:
tab cohort bio if commid == "431"
drop if commid == "431"

* Remove individuals with same-sex relationships:
sort aid
merge aid using temp_samesex, nokeep keep(homosex)
drop if homosex == 1

* Save base file with individual characteristics and group identifiers:
keep bio_sex cohort puberty ovrwgt hisp black younger only mom_mar upinc paredu pborn expcoll urban aregion grd9sep commid scid aid iyear imonth
order bio_sex cohort puberty ovrwgt hisp black younger only mom_mar upinc paredu pborn expcoll urban aregion grd9sep commid scid aid iyear imonth

compress
sort aid
save variables_R.dta, replace



// DYNAMIC ESTIMATION FILE

use variables_R

* Merge with quarterly virginity status:
destring aid, gen(id)
sort id
merge id using quarterly, keep(t nonvirg)
tab _m
keep if _m == 3
drop _m

* Set panel:
tsset id t

* Remove observations from summer 1996
drop if t == 146

* Remove observations that drop out early (except 12th grade cohort):
by id: egen complete = max(t)
replace complete = (complete==145 | complete==146)
keep if complete == 1 | cohort == 12
drop complete

* Set base period t=0:
replace t = t - 138

* Reshape to "wide" dataset:
rename nonvirg nonvirg_
reshape wide nonvirg_ , i(id) j(t)

* Peer group populations:
bysort commid cohort bio: egen pop_P = count(nonvirg_0)

* Save:
compress
sort id
saveold dynamic_R.dta, replace



// MAKE FILES WITH AGGREGATE NONVIRGINITY RATES
* (used to estimate equilibrium approximation)

// A) Generate Nonvirginity Rates

use quarterly

* Set panel and remove summer 1996:
tsset id t
drop if t == 146

* Remove observations that drop out early (except 12th grade cohort):
by id: egen complete = max(t)
replace complete = (complete==145 | complete==146)
keep if complete == 1 | cohort == 12
drop complete

* Restrict to match estimation sample:
merge id using dynamic_R, keep(id)
tab _m
keep if _m==3
drop _m

* Collapse to aggregate by school-grade-sex cohorts:
collapse (mean) hbar_ = nonvirg (count) pop_ = nonvirg, by(commid cohort bio_sex t)
compress

* Reshape dataset so that each observation has both genders:
reshape wide hbar_ pop_, i(commid cohort t) j(bio_sex)

* Use time series operators to make supply groups:
* (i.e., certain grades of the opposite gender, the endogenous "market")
gen com_t = commid*1000 + t
tsset com_t cohort

gen market0_2 = hbar_1
gen market1_2 = F1.hbar_1
gen market2_2 = F2.hbar_1
gen market0_1 = hbar_2
gen market1_1 = L1.hbar_2
gen market2_1 = F1.hbar_2

* Reshape back to have separate observations by gender:
drop com_t
reshape long hbar_ pop_ market0_ market1_ market2_, i(commid cohort t) j(bio_sex)

* Clean up variable names:
rename bio_sex gen
rename hbar_ hbar
rename pop_ pop
forvalues N = 0/2 {
  rename market`N'_ market`N'
  }

* Grade variable:
gen byte grd = cohort + (t > 142)

* Replace missing supply group rates with zeros where appropriate:
replace market1 = 0 if gen == 1 &  grd == 9
replace market2 = 0 if gen == 1 &  grd == 12
replace market1 = 0 if gen == 2 &  grd == 12
replace market2 = 0 if gen == 2 & (grd == 11 | grd ==12)

* Identifier for school-grade-sex groups:
gen aggid = 1000*commid + 10*cohort + gen

// B) Make Quarterly File

* Generate quarterly lags of peer and supply group rates:
tsset aggid t

gen ownlag = L1.hbar
gen firstdiff = D1.hbar
gen mktlag0 = L1.market0
gen mktlag1 = L1.market1
gen mktlag2 = L1.market2

* Save file with quarterly lags:
saveold agg_qtr, replace

// C) Make Annual File

* Replace quarterly lags with annual lags:
drop ownlag-mktlag2

gen ownlag = L4.hbar
gen firstdiff = S4.hbar
gen mktlag0 = L4.market0
gen mktlag1 = L4.market1
gen mktlag2 = L4.market2

* Save file with annual lags:
saveold agg_ann, replace

// D) File with Vector of Current Nonvirginity Rates

* Restrict variables and grades:
keep commid t gen grd hbar
drop if grd == 13

* Reshape data:

tostring gen, replace
replace gen = "b" if gen == "1"
replace gen = "g" if gen == "2"

rename hbar hbar_ 

reshape wide hbar_ , i(commid grd t) j(gen) string
reshape wide hbar_b hbar_g, i(commid t) j(grd)

* Replace missing rates with zeros:
foreach var of varlist hbar_*  {
  replace `var' = 0 if `var' == .
  }

* Set base period t=0:
replace t = t - 138

* Organize and save:
order commid t hbar_b7 hbar_b8 hbar_b9 hbar_b10 hbar_b11 hbar_b12 hbar_g7 hbar_g8 hbar_g9 hbar_g10 hbar_g11 hbar_g12

compress
sort commid t
saveold agg_vec, replace
